@@ -2,7 +2,7 @@ from typing import Any
 
 from ffun.librarian import errors
 from ffun.library.entities import Entry
-from ffun.ontology.entities import ProcessorTag
+from ffun.ontology.entities import NormalizationMode, RawTag
 
 
 class Processor:
@@ -15,7 +15,7 @@ class Processor:
     def name(self) -> str:
         return self._name
 
-    async def process(self, entry: Entry) -> list[ProcessorTag]:
+    async def process(self, entry: Entry) -> list[RawTag]:
         raise NotImplementedError('You must implement "process" method in child class')
 
 
@@ -31,12 +31,12 @@ class AlwaysConstantProcessor(Processor):
         super().__init__(**kwargs)
         self._tags = tags
 
-    async def process(self, entry: Entry) -> list[ProcessorTag]:
-        return [ProcessorTag(raw_uid=tag) for tag in self._tags]
+    async def process(self, entry: Entry) -> list[RawTag]:
+        return [RawTag(raw_uid=tag, normalization=NormalizationMode.final) for tag in self._tags]
 
 
 class AlwaysSkipEntryProcessor(Processor):
-    async def process(self, entry: Entry) -> list[ProcessorTag]:
+    async def process(self, entry: Entry) -> list[RawTag]:
         raise errors.SkipEntryProcessing()
 
 
@@ -44,10 +44,10 @@ class AlwaysErrorProcessor(Processor):
     class CustomError(Exception):
         pass
 
-    async def process(self, entry: Entry) -> list[ProcessorTag]:
+    async def process(self, entry: Entry) -> list[RawTag]:
         raise self.CustomError()
 
 
 class AlwaysTemporaryErrorProcessor(Processor):
-    async def process(self, entry: Entry) -> list[ProcessorTag]:
+    async def process(self, entry: Entry) -> list[RawTag]:
         raise errors.TemporaryErrorInProcessor()
