@@ -1,3 +1,4 @@
+import datetime
 import functools
 import pathlib
 
@@ -12,9 +13,10 @@ _root = pathlib.Path(__file__).parent
 
 
 class Settings(BaseSettings):
-    # TODO: add to documentation/README
     tag_processors_config: pathlib.Path = _root / "fixtures" / "tag_processors.toml"
 
+    metric_accumulation_interval: datetime.timedelta = datetime.timedelta(minutes=10)
+
     @pydantic.computed_field  # type: ignore
     @functools.cached_property
     def tag_processors(self) -> tuple[TagProcessor, ...]:
