@@ -2,25 +2,31 @@ import uuid
 
 import pytest
 
+from ffun.core import utils
 from ffun.core.postgresql import execute, transaction
 from ffun.core.tests.helpers import Delta, TableSizeDelta, TableSizeNotChanged
 from ffun.domain.entities import EntryId, TagId, TagUid
+from ffun.feeds.entities import Feed
 from ffun.library.entities import Entry
+from ffun.library.tests import make as l_make
 from ffun.ontology import errors
 from ffun.ontology.domain import apply_tags_to_entry
-from ffun.ontology.entities import ProcessorTag, TagCategory, TagPropertyType
+from ffun.ontology.entities import NormalizedTag, TagCategory, TagPropertyType
 from ffun.ontology.operations import (
     _get_relations_for_entry_and_tags,
     _register_relations_processors,
     _save_tags,
     apply_tags,
     apply_tags_properties,
+    count_new_tags_at,
     count_total_tags,
     count_total_tags_per_category,
     count_total_tags_per_type,
     get_or_create_id_by_tag,
     get_tags_properties,
+    register_tag,
     remove_relations_for_entries,
+    tag_frequency_statistics,
     tech_copy_relations,
 )
 from ffun.ontology.tests.helpers import assert_has_tags
@@ -281,18 +287,16 @@ class TestApplyTagsProperties:
     async def test_first_time_save(
         self,
         three_tags_by_uids: dict[TagUid, TagId],
-        three_processor_tags: tuple[ProcessorTag, ProcessorTag, ProcessorTag],
+        three_processor_tags: tuple[NormalizedTag, NormalizedTag, NormalizedTag],
         fake_processor_id: int,
     ) -> None:
 
         properties = []
 
         for tag in three_processor_tags:
-            tag.link = f"https://example.com?{tag.raw_uid}"
+            tag.link = f"https://example.com?{tag.uid}"
             properties.extend(
-                tag.build_properties_for(
-                    tag_id=three_tags_by_uids[tag.raw_uid], processor_id=fake_processor_id  # type: ignore
-                )
+                tag.build_properties_for(tag_id=three_tags_by_uids[tag.uid], processor_id=fake_processor_id)
             )
 
         async with TableSizeDelta("o_tags_properties", delta=3):
@@ -309,18 +313,16 @@ class TestApplyTagsProperties:
     async def test_save_duplicated(
         self,
         three_tags_by_uids: dict[TagUid, TagId],
-        three_processor_tags: tuple[ProcessorTag, ProcessorTag, ProcessorTag],
+        three_processor_tags: tuple[NormalizedTag, NormalizedTag, NormalizedTag],
         fake_processor_id: int,
     ) -> None:
 
         properties = []
 
         for tag in three_processor_tags:
-            tag.link = f"https://example.com?{tag.raw_uid}"
+            tag.link = f"https://example.com?{tag.uid}"
             properties.extend(
-                tag.build_properties_for(
-                    tag_id=three_tags_by_uids[tag.raw_uid], processor_id=fake_processor_id  # type: ignore
-                )
+                tag.build_properties_for(tag_id=three_tags_by_uids[tag.uid], processor_id=fake_processor_id)
             )
 
         async with TableSizeDelta("o_tags_properties", delta=3):
@@ -347,18 +349,16 @@ class TestApplyTagsProperties:
     async def test_error_on_duplicated_properties(
         self,
         three_tags_by_uids: dict[TagUid, TagId],
-        three_processor_tags: tuple[ProcessorTag, ProcessorTag, ProcessorTag],
+        three_processor_tags: tuple[NormalizedTag, NormalizedTag, NormalizedTag],
         fake_processor_id: int,
     ) -> None:
 
         properties = []
 
         for tag in three_processor_tags:
-            tag.link = f"https://example.com?{tag.raw_uid}"
+            tag.link = f"https://example.com?{tag.uid}"
             properties.extend(
-                tag.build_properties_for(
-                    tag_id=three_tags_by_uids[tag.raw_uid], processor_id=fake_processor_id  # type: ignore
-                )
+                tag.build_properties_for(tag_id=three_tags_by_uids[tag.uid], processor_id=fake_processor_id)
             )
 
         properties.append(properties[0])
@@ -380,14 +380,14 @@ class TestCountTotalTagsPerCategory:
 
     @pytest.mark.asyncio
     async def test(self, cataloged_entry: Entry) -> None:
-        tags = [uuid.uuid4().hex for _ in range(5)]
+        tags = [TagUid(uuid.uuid4().hex) for _ in range(5)]
 
         processor_tags = [
-            ProcessorTag(raw_uid=tags[0]),
-            ProcessorTag(raw_uid=tags[1], categories={TagCategory.network_domain}),
-            ProcessorTag(raw_uid=tags[2], categories={TagCategory.feed_tag}),
-            ProcessorTag(raw_uid=tags[3], categories={TagCategory.network_domain, TagCategory.feed_tag}),
-            ProcessorTag(raw_uid=tags[4], categories={TagCategory.feed_tag}),
+            NormalizedTag(uid=tags[0], link=None, categories=set()),
+            NormalizedTag(uid=tags[1], link=None, categories={TagCategory.network_domain}),
+            NormalizedTag(uid=tags[2], link=None, categories={TagCategory.feed_tag}),
+            NormalizedTag(uid=tags[3], link=None, categories={TagCategory.network_domain, TagCategory.feed_tag}),
+            NormalizedTag(uid=tags[4], link=None, categories={TagCategory.feed_tag}),
         ]
 
         numbers_before = await count_total_tags_per_category()
@@ -404,14 +404,14 @@ class TestCountTotalTagsPerType:
 
     @pytest.mark.asyncio
     async def test(self, cataloged_entry: Entry) -> None:
-        tags = [uuid.uuid4().hex for _ in range(5)]
+        tags = [TagUid(uuid.uuid4().hex) for _ in range(5)]
 
         processor_tags = [
-            ProcessorTag(raw_uid=tags[0]),
-            ProcessorTag(raw_uid=tags[1], link="https://example.com"),
-            ProcessorTag(raw_uid=tags[2], link="https://example.com", categories={TagCategory.network_domain}),
-            ProcessorTag(raw_uid=tags[3], link="https://example.com", categories={TagCategory.feed_tag}),
-            ProcessorTag(raw_uid=tags[4], link="https://example.com"),
+            NormalizedTag(uid=tags[0], link=None, categories=set()),
+            NormalizedTag(uid=tags[1], link="https://example.com", categories=set()),
+            NormalizedTag(uid=tags[2], link="https://example.com", categories={TagCategory.network_domain}),
+            NormalizedTag(uid=tags[3], link="https://example.com", categories={TagCategory.feed_tag}),
+            NormalizedTag(uid=tags[4], link="https://example.com", categories=set()),
         ]
 
         numbers_before = await count_total_tags_per_type()
@@ -424,5 +424,52 @@ class TestCountTotalTagsPerType:
         assert numbers_after[TagPropertyType.categories] == numbers_before.get(TagPropertyType.categories, 0) + 2
 
 
+class TestCountNewTagsAt:
+
+    @pytest.mark.asyncio
+    async def test(self) -> None:
+        count_before = await count_new_tags_at(utils.now().date())
+
+        for _ in range(3):
+            await register_tag(TagUid(uuid.uuid4().hex))
+
+        count_after = await count_new_tags_at(utils.now().date())
+
+        assert count_after == count_before + 3
+
+
 class TestGetTagsForEntries:
     """Tested in other tests & code."""
+
+
+class TestTagFrequencyStatistics:
+
+    @pytest.mark.asyncio
+    async def test(
+        self, saved_feed: Feed, fake_processor_id: int, five_tags_ids: tuple[TagId, TagId, TagId, TagId, TagId]
+    ) -> None:
+        buckets = [1, 2, 3, 5, 7]
+        tags = five_tags_ids
+
+        stats_before = await tag_frequency_statistics(buckets)
+
+        entries = await l_make.n_entries_list(saved_feed, 8)
+
+        for entry in entries[:3]:
+            await apply_tags(execute, entry.id, fake_processor_id, [tags[0]])
+
+        for entry in entries[:5]:
+            await apply_tags(execute, entry.id, fake_processor_id, [tags[1], tags[2]])
+
+        for entry in entries:
+            await apply_tags(execute, entry.id, fake_processor_id, [tags[3]])
+
+        stats_after = await tag_frequency_statistics(buckets)
+
+        assert len(stats_before) == len(buckets) == len(stats_after)
+
+        assert stats_before[0] == stats_after[0]
+        assert stats_before[1] == stats_after[1]
+        assert stats_before[2].replace(count=stats_before[2].count + 1) == stats_after[2]
+        assert stats_before[3].replace(count=stats_before[3].count + 2) == stats_after[3]
+        assert stats_before[4].replace(count=stats_before[4].count + 1) == stats_after[4]
